# Mixins package 
from acl_package.mixins.permission_mixin import PermissionMixin 
 
__all__ = ['PermissionMixin'] 
from acl_package.mixins.permission_mixin import PermissionMixin 
__all__ = ['PermissionMixin'] 
 
