class RolePermission:

    def __init__(self,id,role_id,permission_id,created_at=None):
        self.id = id
        self.role_id = role_id
        self.permission_id = permission_id
        self.created_at = created_at