class PermissionRegistry:
    def __init__(self):
        self.permissions = {}

    def add_permission(self, permission_obj):
        self.permissions[permission_obj.permission_name] = permission_obj