
class GroupRole:
    def __init__(self, id, group_id, role_id, created_at=None):
        self.id = id
        self.group_id = group_id
        self.role_id = role_id
        self.created_at = created_at