
from acl_package.mixins.permission_mixin import PermissionMixin

class User(PermissionMixin):
    def __init__(self, id, username, email, password, is_super_admin, is_admin, created_at=None):
        self.id = id
        self.username = username
        self.email = email
        self.password = password
        self.is_super_admin = is_super_admin
        self.is_admin = is_admin
        self.created_at = created_at
        self.roles = []
        self.groups = []
        self.object_permissions = []