class ObjectPermission:

    def __init__(self,id,user,group_id,object_type,object_id,permission_name,created_at=None):
        self.id = id
        self.user = user
        self.group_id = group_id
        self.object_type=object_type
        self.object_id=object_id
        self.permission_name=permission_name
        self.created_at = created_at

        