

class Permission:
    def __init__(self, id, permission_name, label, created_at=None):
        self.id = id
        self.permission_name = permission_name
        self.label = label
        self.created_at = created_at