class UserRole:

    def __init__(self,id,user_id,role_id,created_at=None):
        self.id = id
        self.user_id = user_id
        self.role_id = role_id
        self.created_at = created_at

        