from setuptools import setup, find_packages

setup(
    name='aclforall',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[], 
    author='Your Name',
    description='ACL package for permission management',
    python_requires='>=3.6',
)